@@ -38,6 +38,11 @@
 #include "libcryptsetup.h"
 #include "internal.h"
 
+unsigned crypt_getpagesize(void)
+{
+	return (unsigned)sysconf(_SC_PAGESIZE);
+}
+
 static int get_alignment(int fd)
 {
 	int alignment = DEFAULT_MEM_ALIGNMENT;
@@ -416,17 +421,6 @@ int device_check_and_adjust(struct crypt_device *cd,
 		return -EINVAL;
 	}
 
-	if (device_check == DEV_SHARED) {
-		log_dbg("Checking crypt segments for device %s.", device);
-		r = crypt_sysfs_check_crypt_segment(device, *offset, *size);
-		if (r < 0) {
-			log_err(cd, _("Cannot use device %s (crypt segments "
-				    "overlaps or in use by another device).\n"),
-				    device);
-			return r;
-		}
-	}
-
 	if (real_readonly)
 		*flags |= CRYPT_ACTIVATE_READONLY;
 
